summaryrefslogtreecommitdiff
path: root/include/system.h
diff options
context:
space:
mode:
authorDiana Z <dzigterman@chromium.org>2020-10-30 15:08:03 -0600
committerCommit Bot <commit-bot@chromium.org>2020-10-31 01:06:10 +0000
commitc52033d763d7b63978e3207a33725a2c9ff2aff3 (patch)
treefb9646377b325ed5d627b7ff2433334211911463 /include/system.h
parent63e4dcbe22f2b987e3040a1a8a39720fb4cd55bf (diff)
downloadchrome-ec-c52033d763d7b63978e3207a33725a2c9ff2aff3.tar.gz
COIL: Rename SLEEP_MASK_I2C_PERIPHERAL
Rename SLEEP_MASK_I2C_PERIPHERAL and related comments. BRANCH=None BUG=None TEST=make -j buildall Signed-off-by: Diana Z <dzigterman@chromium.org> Change-Id: Idaeefda102c603a38f128d820ed1f647069eaeea Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2511094 Reviewed-by: Daisuke Nojiri <dnojiri@chromium.org>
Diffstat (limited to 'include/system.h')
-rw-r--r--include/system.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/include/system.h b/include/system.h
index 965bf93abc..7c540e1d5e 100644
--- a/include/system.h
+++ b/include/system.h
@@ -466,7 +466,7 @@ enum {
SLEEP_MASK_USB_PWR = BIT(4), /* USB power loop ongoing */
SLEEP_MASK_USB_PD = BIT(5), /* USB PD device connected */
SLEEP_MASK_SPI = BIT(6), /* SPI communications ongoing */
- SLEEP_MASK_I2C_SLAVE = BIT(7), /* I2C slave communication ongoing */
+ SLEEP_MASK_I2C_PERIPHERAL = BIT(7), /* I2C peripheral comms ongoing */
SLEEP_MASK_FAN = BIT(8), /* Fan control loop ongoing */
SLEEP_MASK_USB_DEVICE = BIT(9), /* Generic USB device in use */
SLEEP_MASK_PWM = BIT(10), /* PWM output is enabled */